==> QupZilla-2.0.0.tar.xz: QupZilla-2.0.0/src/plugins/PIM/translations/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_PT" version="2.0">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>Last Name</source>
        <translation>Apelido</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>First Name</source>
        <translation>Nome próprio</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>E-mail</source>
        <translation>Endereço eletrónico</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Mobile</source>
        <translation>Telemóvel</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Phone</source>
        <translation>Telefone</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>Address</source>
        <translation>Morada</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>City</source>
        <translation>Cidade</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>ZIP Code</source>
        <translation>Código postal</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>State/Region</source>
        <translation>Distrito/Região</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Country</source>
        <translation>País</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Home Page</source>
        <translation>Página web</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 1</source>
        <translation>Personalizado 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 2</source>
        <translation>Personalizado 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="73"/>
        <source>Custom 3</source>
        <translation>Personalizado 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="115"/>
        <source>Insert Personal Information</source>
        <translation>Indique as informações pessoais</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="136"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Gestor de informações pessoais&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>As suas informações serão utilizadas nas páginas web.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Nome próprio:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Apelido:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>Endereço eletrónico:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Telefone:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Telemóvel:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Morada:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Cidade:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Código postal:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Distrito/Região:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>País:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Página web:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Personalizado 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Personalizado 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Personalizado 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Prima Ctrl+ENTER para preencher automaticamente os formulários com os dados pessoais.</translation>
    </message>
</context>
</TS>

==> QupZilla-2.1.2.tar.xz: QupZilla-2.1.2/src/plugins/PIM/translations/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_PT" version="2.1">
<context>
    <name>PIM_Handler</name>
    <message>
        <location filename="../PIM_handler.cpp" line="59"/>
        <source>Last Name</source>
        <translation>Apelido</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="60"/>
        <source>First Name</source>
        <translation>Nome próprio</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="61"/>
        <source>E-mail</source>
        <translation>Endereço eletrónico</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="62"/>
        <source>Mobile</source>
        <translation>Telemóvel</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="63"/>
        <source>Phone</source>
        <translation>Telefone</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="64"/>
        <source>Address</source>
        <translation>Morada</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="65"/>
        <source>City</source>
        <translation>Cidade</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="66"/>
        <source>ZIP Code</source>
        <translation>Código postal</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="67"/>
        <source>State/Region</source>
        <translation>Distrito/Região</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="68"/>
        <source>Country</source>
        <translation>País</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="69"/>
        <source>Home Page</source>
        <translation>Página inicial</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="70"/>
        <source>Custom 1</source>
        <translation>Personalizado 1</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="71"/>
        <source>Custom 2</source>
        <translation>Personalizado 2</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="72"/>
        <source>Custom 3</source>
        <translation>Personalizado 3</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="114"/>
        <source>Insert Personal Information</source>
        <translation>Indique as informações pessoais</translation>
    </message>
    <message>
        <location filename="../PIM_handler.cpp" line="135"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
</context>
<context>
    <name>PIM_Settings</name>
    <message>
        <location filename="../PIM_settings.ui" line="14"/>
        <source>PIM Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="42"/>
        <source>&lt;h2&gt;Personal Information Manager&lt;/h2&gt;</source>
        <translation>&lt;h2&gt;Gestor de informações pessoais&lt;/h2&gt;</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="64"/>
        <source>Your personal information that will be used on webpages.</source>
        <translation>As suas informações pessoais serão utilizadas nas páginas web.</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="76"/>
        <source>First Name:</source>
        <translation>Nome próprio:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="89"/>
        <source>Last Name:</source>
        <translation>Apelido:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="102"/>
        <source>E-mail:</source>
        <translation>Endereço eletrónico:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="115"/>
        <source>Phone:</source>
        <translation>Telefone:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="128"/>
        <source>Mobile Phone:</source>
        <translation>Telemóvel:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="141"/>
        <source>Address:</source>
        <translation>Morada:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="154"/>
        <source>City:</source>
        <translation>Cidade:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="167"/>
        <source>ZIP Code:</source>
        <translation>Código postal:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="180"/>
        <source>State/Region:</source>
        <translation>Distrito/Região:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="193"/>
        <source>Country:</source>
        <translation>País:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="206"/>
        <source>Home Page:</source>
        <translation>Página inicial:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="219"/>
        <source>Custom 1:</source>
        <translation>Personalizado 1:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="232"/>
        <source>Custom 2:</source>
        <translation>Personalizado 2:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="245"/>
        <source>Custom 3:</source>
        <translation>Personalizado 3:</translation>
    </message>
    <message>
        <location filename="../PIM_settings.ui" line="260"/>
        <source>&lt;b&gt;Note:&lt;/b&gt; Press Ctrl+ENTER to autofill form fields for which QupZilla finds personal entries.</source>
        <translation>&lt;b&gt;Nota:&lt;/b&gt; Prima Ctrl+ENTER para preencher automaticamente os formulários com os dados pessoais.</translation>
    </message>
</context>
</TS>
